@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 #--------------------------------------------------------------------------
 
@@ -38,10 +38,10 @@ use JSON;
 ###########################################################################
 # Constants
 
-use constant	SEARCH	=> 'http://openlibrary.org/api/books?jscmd=data&format=json&bibkeys=ISBN:';
-use constant	LB2G    => 453.59237;   # number of grams in a pound (lb)
-use constant	OZ2G    => 28.3495231;  # number of grams in an ounce (oz)
-use constant	IN2MM   => 25.4;        # number of inches in a millimetre (mm)
+use constant SEARCH => 'http://openlibrary.org/api/books?jscmd=data&format=json&bibkeys=ISBN:';
+use constant LB2G   => 453.59237;   # number of grams in a pound (lb)
+use constant OZ2G   => 28.3495231;  # number of grams in an ounce (oz)
+use constant IN2MM  => 25.4;        # number of inches in a millimetre (mm)
 
 #--------------------------------------------------------------------------
 
@@ -85,46 +85,46 @@ The book_link and image_link refer back to the OpenLibrary website.
 =cut
 
 sub search {
-	my $self = shift;
-	my $isbn = shift;
+    my $self = shift;
+    my $isbn = shift;
     my $data;
-	$self->found(0);
-	$self->book(undef);
+    $self->found(0);
+    $self->book(undef);
 
-	my $mech = WWW::Mechanize->new();
+    my $mech = WWW::Mechanize->new();
     $mech->agent_alias( 'Linux Mozilla' );
 
     eval { $mech->get( SEARCH . $isbn ) };
     return $self->handler("OpenLibrary website appears to be unavailable.")
-	    if($@ || !$mech->success() || !$mech->content());
+        if($@ || !$mech->success() || !$mech->content());
 
     my $code = decode_json($mech->content());
 #use Data::Dumper;
 #print STDERR "\n# code=".Dumper($code);
 
     return $self->handler("Failed to find that book on OpenLibrary website.")
-	    unless($code->{'ISBN:'.$isbn});
+        unless($code->{'ISBN:'.$isbn});
 
     $data->{isbn13}         = $code->{'ISBN:'.$isbn}{identifiers}{isbn_13}[0];
     $data->{isbn10}         = $code->{'ISBN:'.$isbn}{identifiers}{isbn_10}[0];
 
     return $self->handler("Failed to find that book on OpenLibrary website.")
-	    unless($isbn eq $data->{isbn13} || $isbn eq $data->{isbn10});
+        unless($isbn eq $data->{isbn13} || $isbn eq $data->{isbn10});
 
 #use Data::Dumper;
 #print STDERR "\n# " . Dumper($data);
 
-    $data->{isbn13}         = $code->{'ISBN:'.$isbn}{identifiers}{isbn_13}[0];
-    $data->{isbn10}         = $code->{'ISBN:'.$isbn}{identifiers}{isbn_10}[0];
-    $data->{image}          = $code->{'ISBN:'.$isbn}{cover}{large};
-    $data->{thumb}          = $code->{'ISBN:'.$isbn}{cover}{small};
-    $data->{author}         = $code->{'ISBN:'.$isbn}{authors}[0]{name};
-    $data->{title}          = $code->{'ISBN:'.$isbn}{title};
-    $data->{publisher}      = $code->{'ISBN:'.$isbn}{publishers}[0]{name};
-    $data->{pubdate}        = $code->{'ISBN:'.$isbn}{publish_date};
-    $data->{pages}          = $code->{'ISBN:'.$isbn}{number_of_pages};
-    $data->{url}            = $code->{'ISBN:'.$isbn}{url};
-    $data->{weight}         = $code->{'ISBN:'.$isbn}{weight};
+    $data->{isbn13}    = $code->{'ISBN:'.$isbn}{identifiers}{isbn_13}[0];
+    $data->{isbn10}    = $code->{'ISBN:'.$isbn}{identifiers}{isbn_10}[0];
+    $data->{image}     = $code->{'ISBN:'.$isbn}{cover}{large};
+    $data->{thumb}     = $code->{'ISBN:'.$isbn}{cover}{small};
+    $data->{author}    = $code->{'ISBN:'.$isbn}{authors}[0]{name};
+    $data->{title}     = $code->{'ISBN:'.$isbn}{title};
+    $data->{publisher} = $code->{'ISBN:'.$isbn}{publishers}[0]{name};
+    $data->{pubdate}   = $code->{'ISBN:'.$isbn}{publish_date};
+    $data->{pages}     = $code->{'ISBN:'.$isbn}{number_of_pages};
+    $data->{url}       = $code->{'ISBN:'.$isbn}{url};
+    $data->{weight}    = $code->{'ISBN:'.$isbn}{weight};
 
     if($data->{weight}&& $data->{weight} =~ /([\d.]+)\s*(?:lbs|pounds)/) {
         $data->{weight} = int($1 * LB2G);
@@ -138,16 +138,16 @@ sub search {
 
     eval { $mech->get( $data->{url} ) };
     return $self->handler("OpenLibrary website appears to be unavailable.")
-	    if($@ || !$mech->success() || !$mech->content());
+        if($@ || !$mech->success() || !$mech->content());
 
-	# The Book page
+    # The Book page
     my $html = $mech->content();
 #print STDERR "\n# html=[\n$html\n]\n";
 
     # catch any data not in the JSON
     ($data->{height},$data->{width},$data->{depth})    
-                                        = $html =~ m!<td class="title"><span class="title">Dimensions</span></td>\s*<td><span class="object">([\d.]+)\s+x\s+([\d.]+)\s+x\s+([\d.]+)\s+inches!i;
-    ($data->{binding})                  = $html =~ m!<td class="title"><span class="title">Format</span></td>\s*<td><span class="object">([^<]+)!i;
+                       = $html =~ m!<dt>Dimensions</dt>\s*<dd class="object">([\d.]+)\s+x\s+([\d.]+)\s+x\s+([\d.]+)\s+inches!si;
+    ($data->{binding}) = $html =~ m!<dt>Format</dt>\s*<dd class="object">([^<]+)!si;
 
     $data->{height} = int($data->{height} * IN2MM)  if($data->{height});
     $data->{width}  = int($data->{width}  * IN2MM)  if($data->{width});
@@ -156,40 +156,40 @@ sub search {
 #use Data::Dumper;
 #print STDERR "\n# " . Dumper($data);
 
-	return $self->handler("Could not extract data from OpenLibrary result page.")
-		unless(defined $data);
+    return $self->handler("Could not extract data from OpenLibrary result page.")
+        unless(defined $data);
 
-	# trim top and tail
-	foreach (keys %$data) { next unless(defined $data->{$_});$data->{$_} =~ s/^\s+//;$data->{$_} =~ s/\s+$//; }
+    # trim top and tail
+    foreach (keys %$data) { next unless(defined $data->{$_});$data->{$_} =~ s/^\s+//;$data->{$_} =~ s/\s+$//; }
 
-	my $bk = {
-		'ean13'		    => $data->{isbn13},
-		'isbn13'		=> $data->{isbn13},
-		'isbn10'		=> $data->{isbn10},
-		'isbn'			=> $data->{isbn13},
-		'author'		=> $data->{author},
-		'title'			=> $data->{title},
-		'book_link'		=> $mech->uri(),
-		'image_link'	=> $data->{image},
-		'thumb_link'	=> $data->{thumb},
-		'pubdate'		=> $data->{pubdate},
-		'publisher'		=> $data->{publisher},
-		'binding'	    => $data->{binding},
-		'pages'		    => $data->{pages},
-		'weight'		=> $data->{weight},
-		'width'		    => $data->{width},
-		'height'		=> $data->{height},
-		'depth'		    => $data->{depth},
-        'json'          => $code,
-        'html'          => $html
-	};
+    my $bk = {
+        'ean13'      => $data->{isbn13},
+        'isbn13'     => $data->{isbn13},
+        'isbn10'     => $data->{isbn10},
+        'isbn'       => $data->{isbn13},
+        'author'     => $data->{author},
+        'title'      => $data->{title},
+        'book_link'  => $mech->uri(),
+        'image_link' => $data->{image},
+        'thumb_link' => $data->{thumb},
+        'pubdate'    => $data->{pubdate},
+        'publisher'  => $data->{publisher},
+        'binding'    => $data->{binding},
+        'pages'      => $data->{pages},
+        'weight'     => $data->{weight},
+        'width'      => $data->{width},
+        'height'     => $data->{height},
+        'depth'      => $data->{depth},
+        'json'       => $code,
+        'html'       => $html
+    };
 
 #use Data::Dumper;
 #print STDERR "\n# book=".Dumper($bk);
 
     $self->book($bk);
-	$self->found(1);
-	return $self->book;
+    $self->found(1);
+    return $self->book;
 }
 
 1;
@@ -228,7 +228,7 @@ be forthcoming, please feel free to (politely) remind me.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2014 Barbie for Miss Barbell Productions
+  Copyright (C) 2010-2019 Barbie for Miss Barbell Productions
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
